package com.mcwl.web.controller.memberCenter;


import cn.hutool.core.bean.BeanUtil;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.memberCenter.domain.MemberPromotion;
import com.mcwl.memberCenter.domain.Promotion;
import com.mcwl.memberCenter.domain.dto.JoinPromotionDto;
import com.mcwl.memberCenter.domain.dto.PromotionDto;
import com.mcwl.memberCenter.enums.PromotionEnum;
import com.mcwl.memberCenter.service.MemberPromotionService;
import com.mcwl.memberCenter.service.PromotionService;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.Date;
import java.util.List;
import java.util.Optional;


/**
 * 促销活动
 */
@RestController
@RequestMapping("promotion")
@RequiredArgsConstructor
public class PromotionController {

    private final PromotionService promotionService;

    private final MemberPromotionService memberPromotionService;


    /**
     * 创建活动
     */
    @PostMapping("createPromotion")
    public AjaxResult createPromotion(@RequestBody @Valid PromotionDto promotionDto) {

        Promotion promotion = new Promotion();

        BeanUtil.copyProperties(promotionDto, promotion);

        promotionService.save(promotion);

        return AjaxResult.success();
    }


    /**
     * 活动列表
     */
    @GetMapping("promotionList")
    public AjaxResult promotionList() {
        List<Promotion> promotionList = promotionService.lambdaQuery()
                .lt(Promotion::getEndTime, new Date())
                .list();
        return AjaxResult.success(promotionList);
    }

    /**
     * 获取当前用户参与的活动
     */
    @GetMapping("myPromotionList")
    public AjaxResult myPromotionList() {
        // 获取当前用户
        Long userId = SecurityUtils.getUserId();
        List<MemberPromotion> memberPromotionList = memberPromotionService.lambdaQuery()
                .eq(MemberPromotion::getMemberId, userId)
                .list();
        return AjaxResult.success(memberPromotionList);
    }

    /**
     * 参与活动
     */
    @PostMapping("joinPromotion")
    public AjaxResult joinPromotion(@RequestBody @Valid JoinPromotionDto joinPromotionDto) {
        // 用户id
        Long userId = joinPromotionDto.getUserId();
        // 活动id
        Long promotionId = joinPromotionDto.getPromotionId();
        // 按活动id查询活动信息
        Promotion promotion = promotionService.getById(promotionId);

        if (!Optional.ofNullable(promotion).isPresent()) {
            return AjaxResult.warn("活动不存在");
        }

        if (promotion.getStartTime().after(new Date())) {
            return AjaxResult.warn("活动未开始");
        }

        // 活动是否过期
        if (promotion.getEndTime().before(new Date())) {
            return AjaxResult.warn("活动已过期");
        }

        String memberLevelIds = promotion.getMemberLevelId();
        if (!memberLevelIds.contains(userId.toString())) {
            return AjaxResult.warn("无法参与该活动，请查看活动条件");
        }
        MemberPromotion memberPromotion = new MemberPromotion();
        memberPromotion.setMemberId(userId);
        memberPromotion.setPromotionId(promotionId);
        memberPromotion.setStatus(PromotionEnum.EXPIRED);
        memberPromotion.setParticipationTime(new Date());
        memberPromotionService.save(memberPromotion);


        return AjaxResult.success();
    }


}
