package com.mcwl.web.controller.pay;

import cn.hutool.extra.qrcode.QrCodeUtil;
import com.mcwl.common.core.controller.BaseController;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.common.domain.IdsParam;
import com.mcwl.common.interfaces.NoLogin;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.pay.domain.OrderTrade;
import com.mcwl.pay.service.OrderTradeService;
import com.mcwl.resource.domain.MallProduct;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Objects;

import static com.mcwl.common.utils.PageUtils.startPage;

/**
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.web.controller.pay
 * @Filename：OrderTradeController
 * @Description 支付模块
 * @Date：2025/1/3 14:46
 */

@RestController
@RequestMapping("/web/pay")
@Validated
public class OrderTradeController extends BaseController {

    @Autowired
    private OrderTradeService orderTradeService;

    @Autowired
    private AliPayIntegration aliPayIntegration;

    /**
     * 查询列表
     */
    @GetMapping("/list")
    public TableDataInfo list(OrderTrade orderTrade)
    {
        startPage();
        List<OrderTrade> list = orderTradeService.selectMallProductList(orderTrade);
        return getDataTable(list);
    }

    /**
     * 新增
     */
    @PostMapping("/add")
    public AjaxResult add(@RequestBody OrderTrade orderTrade)
    {
        // 获取当前用户
        Long userId = SecurityUtils.getUserId();
        if (userId == null) {
            return AjaxResult.warn("用户未登录");
        }
        orderTrade.setUserId(userId);
        orderTrade.setCreateBy(getUsername());
        return toAjax(orderTradeService.insertMallProduct(orderTrade));
    }

    /**
     * 修改
     */
    @PostMapping("/upda")
    public AjaxResult upda(@RequestBody OrderTrade orderTrade)
    {
        // 获取当前用户
        Long userId = SecurityUtils.getUserId();
        if (userId == null) {
            return AjaxResult.warn("用户未登录");
        }
        orderTrade.setUserId(userId);
        orderTrade.setUpdateBy(getUsername());
        return toAjax(orderTradeService.updateMallProduct(orderTrade));
    }

    /**
     * 删除
     */
    @PostMapping
    public AjaxResult remove(@RequestBody IdsParam ids)
    {
        orderTradeService.deleteMallProductByIds(ids);
        return success();
    }


    /**
     * 支付接口
     *
     * @param tradeEntity 订单实体
     * @param response    响应
     * @throws Exception
     */
    @NoLogin
    @PostMapping("/doPay")
    public void doPay(@RequestBody OrderTrade tradeEntity, HttpServletResponse response) throws Exception {
        String qrUrl = aliPayIntegration.pay(tradeEntity);
        QrCodeUtil.generate(qrUrl, 300, 300, "png", response.getOutputStream());
    }


}
