package com.mcwl.pay.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mcwl.common.domain.IdsParam;
import com.mcwl.common.utils.StringUtils;
import com.mcwl.pay.domain.OrderTrade;
import com.mcwl.pay.domain.PaymentResult;
import com.mcwl.pay.domain.enums.PaymentStatus;
import com.mcwl.pay.mapper.OrderTradeMapper;
import com.mcwl.pay.service.OrderTradeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;

/**
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.pay.service.impl
 * @Filename：OrderTradeServiceImpl
 * @Description TODO
 * @Date：2025/1/3 14:51
 */
@Service
public class OrderTradeServiceImpl extends ServiceImpl<OrderTradeMapper, OrderTrade> implements OrderTradeService {

   @Autowired
   private OrderTradeMapper orderTradeMapper;

    @Override
    public List<OrderTrade> selectMallProductList(OrderTrade orderTrade) {
        // 创建一个 LambdaQueryWrapper 实例
        LambdaQueryWrapper<OrderTrade> queryWrapper = new LambdaQueryWrapper<>();

        // 使用非空检查来添加查询条件
        if (StringUtils.isNotNull(orderTrade.getCode())) {
            queryWrapper.eq(OrderTrade::getCode, orderTrade.getCode());
        }
        if (StringUtils.isNotNull(orderTrade.getUserId())) {
            queryWrapper.eq(OrderTrade::getUserId, orderTrade.getUserId());
        }
        if (StringUtils.isNotNull(orderTrade.getProductId())) {
            queryWrapper.eq(OrderTrade::getProductId, orderTrade.getProductId());
        }
        if (StringUtils.isNotNull(orderTrade.getProductName())) {
            queryWrapper.like(OrderTrade::getProductName, orderTrade.getProductName());
        }
        if (StringUtils.isNotNull(orderTrade.getUserName())) {
            queryWrapper.eq(OrderTrade::getUserName, orderTrade.getUserName());
        }
        if (StringUtils.isNotNull(orderTrade.getOrderTime())) {
            queryWrapper.eq(OrderTrade::getOrderTime, orderTrade.getOrderTime());
        }
        if (StringUtils.isNotNull(orderTrade.getOrderStatus())) {
            queryWrapper.eq(OrderTrade::getOrderStatus, orderTrade.getOrderStatus());
        }
        if (StringUtils.isNotNull(orderTrade.getPayStatus())) {
            queryWrapper.eq(OrderTrade::getPayStatus, orderTrade.getPayStatus());
        }
        if (StringUtils.isNotNull(orderTrade.getTotalAmount())) {
            queryWrapper.eq(OrderTrade::getTotalAmount, orderTrade.getTotalAmount());
        }
        if (StringUtils.isNotNull(orderTrade.getPaymentAmount())) {
            queryWrapper.eq(OrderTrade::getPaymentAmount, orderTrade.getPaymentAmount());
        }

        return orderTradeMapper.selectList(queryWrapper);
    }


    @Override
    public int insertMallProduct(OrderTrade orderTrade) {
        PaymentResult paymentResult = orderTradeMapper.chargeCard(orderTrade.getTotalAmount(), orderTrade.getPaymentMethod());

        if (paymentResult.isSuccess()) {
            // 支付成功后的处理：更新订单状态、生成激活码、更新用户权限等
            orderTrade.setOrderStatus(PaymentStatus.COMPLETED.ordinal());

            // 保存订单
            return orderTradeMapper.insert(orderTrade);
        } else {
            // 支付失败处理...
            orderTrade.setOrderStatus(PaymentStatus.FAILED.ordinal());
        }
        return 0;
    }

    @Override
    public void deleteMallProductByIds(IdsParam ids) {
        orderTradeMapper.deleteBatchIds(ids.getIds());
    }

    @Override
    public int updateMallProduct(OrderTrade orderTrade) {
        return orderTradeMapper.updateById(orderTrade);
    }




}
