package com.mcwl.resource.service.impl;

import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.resource.domain.SysUserAttention;
import com.mcwl.resource.domain.SysUserInfo;
import com.mcwl.resource.mapper.MallProductLikeMapper;
import com.mcwl.resource.mapper.MallProductMapper;
import com.mcwl.resource.mapper.SysUserAttentionMapper;
import com.mcwl.resource.service.SysUserAttentionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * 关注表 业务实现层
 *
 * @author DaiZibo
 * @date 2025/1/3
 * @apiNote
 */

@Service
public class SysUserAttentionServiceImpl implements SysUserAttentionService {


    @Autowired
    private MallProductMapper mallProductMapper;

    @Autowired
    private MallProductLikeMapper mallProductLikeMapper;

    @Autowired
    private SysUserAttentionMapper sysUserAttentionMapper;

    @Override
    public AjaxResult addAttention(Long userId) {

        //查看是否已关注
        Boolean aBoolean = selectAttention(userId);
        if (aBoolean == true){
            //取关
            sysUserAttentionMapper.deleteByUserId(SecurityUtils.getUserId(),userId);
            return AjaxResult.success(false);
        }

        //关注
        SysUserAttention sysUserAttention = SysUserAttention.builder().userId(SecurityUtils.getUserId())
                .toUserId(userId)
                .createName(SecurityUtils.getUsername())
                .createTime(new Date())
                .build();
        sysUserAttentionMapper.insert(sysUserAttention);
        return AjaxResult.success(true);
    }

    @Override
    public Boolean selectAttention(Long userId) {

        SysUserAttention sysUserAttention = sysUserAttentionMapper.selectAttention(SecurityUtils.getUserId(),userId);

        if (sysUserAttention == null){
            return false;
        }

        return true;
    }

    @Override
    public SysUserInfo selectUserInfo() {

        Long userId = SecurityUtils.getUserId();

        return SysUserInfo.builder().bean(sysUserAttentionMapper.selectBean(userId))
                .download(mallProductMapper.sumNumber(userId))
                .likeCount(mallProductLikeMapper.countLike(userId))
                .attention(sysUserAttentionMapper.selectAttentionCount(userId)).build();
    }
}
